==> ettercap-debug-0.8.3.1-3-x86_64.pkg.tar.zst: usr/src/debug/ettercap/ettercap-0.8.3.1/build-gtk/utils/ef_grammar.h <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_YY_BUILD_ETTERCAP_SRC_ETTERCAP_0_8_3_1_BUILD_GTK_UTILS_EF_GRAMMAR_H_INCLUDED
# define YY_YY_BUILD_ETTERCAP_SRC_ETTERCAP_0_8_3_1_BUILD_GTK_UTILS_EF_GRAMMAR_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    TOKEN_EOL = 258,               /* TOKEN_EOL  */
    TOKEN_CONST = 259,             /* TOKEN_CONST  */
    TOKEN_OFFSET = 260,            /* TOKEN_OFFSET  */
    TOKEN_STRING = 261,            /* TOKEN_STRING  */
    TOKEN_FUNCTION = 262,          /* TOKEN_FUNCTION  */
    TOKEN_IF = 263,                /* TOKEN_IF  */
    TOKEN_ELSE = 264,              /* TOKEN_ELSE  */
    TOKEN_OP_AND = 265,            /* TOKEN_OP_AND  */
    TOKEN_OP_OR = 266,             /* TOKEN_OP_OR  */
    TOKEN_OP_ASSIGN = 267,         /* TOKEN_OP_ASSIGN  */
    TOKEN_OP_INC = 268,            /* TOKEN_OP_INC  */
    TOKEN_OP_DEC = 269,            /* TOKEN_OP_DEC  */
    TOKEN_OP_CMP_NEQ = 270,        /* TOKEN_OP_CMP_NEQ  */
    TOKEN_OP_CMP_EQ = 271,         /* TOKEN_OP_CMP_EQ  */
    TOKEN_OP_CMP_LT = 272,         /* TOKEN_OP_CMP_LT  */
    TOKEN_OP_CMP_GT = 273,         /* TOKEN_OP_CMP_GT  */
    TOKEN_OP_CMP_LEQ = 274,        /* TOKEN_OP_CMP_LEQ  */
    TOKEN_OP_CMP_GEQ = 275,        /* TOKEN_OP_CMP_GEQ  */
    TOKEN_OP_END = 276,            /* TOKEN_OP_END  */
    TOKEN_PAR_OPEN = 277,          /* TOKEN_PAR_OPEN  */
    TOKEN_PAR_CLOSE = 278,         /* TOKEN_PAR_CLOSE  */
    TOKEN_BLK_BEGIN = 279,         /* TOKEN_BLK_BEGIN  */
    TOKEN_BLK_END = 280,           /* TOKEN_BLK_END  */
    TOKEN_UNKNOWN = 281,           /* TOKEN_UNKNOWN  */
    TOKEN_OP_SUB = 282,            /* TOKEN_OP_SUB  */
    TOKEN_OP_ADD = 283,            /* TOKEN_OP_ADD  */
    TOKEN_OP_MUL = 284,            /* TOKEN_OP_MUL  */
    TOKEN_OP_DIV = 285,            /* TOKEN_OP_DIV  */
    TOKEN_UMINUS = 286,            /* TOKEN_UMINUS  */
    TOKET_OP_AND = 287,            /* TOKET_OP_AND  */
    TOKET_OP_OR = 288,             /* TOKET_OP_OR  */
    TOKET_OP_NOT = 289             /* TOKET_OP_NOT  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 42 "etterfilter/ef_grammar.y"

   char *string;
   struct filter_op fop;
   /* used to create the compiler tree */
   struct block *blk;
   struct instruction *ins;
   struct ifblock *ifb;
   struct condition *cnd;

#line 108 "/build/ettercap/src/ettercap-0.8.3.1/build-gtk/utils/ef_grammar.h"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE yylval;


int yyparse (void);


#endif /* !YY_YY_BUILD_ETTERCAP_SRC_ETTERCAP_0_8_3_1_BUILD_GTK_UTILS_EF_GRAMMAR_H_INCLUDED  */

==> ettercap-debug-0.8.3.1-3.1-x86_64.pkg.tar.zst: usr/src/debug/ettercap/ettercap-0.8.3.1/build-gtk/utils/ef_grammar.h <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_YY_STARTDIR_SRC_ETTERCAP_0_8_3_1_BUILD_GTK_UTILS_EF_GRAMMAR_H_INCLUDED
# define YY_YY_STARTDIR_SRC_ETTERCAP_0_8_3_1_BUILD_GTK_UTILS_EF_GRAMMAR_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    TOKEN_EOL = 258,               /* TOKEN_EOL  */
    TOKEN_CONST = 259,             /* TOKEN_CONST  */
    TOKEN_OFFSET = 260,            /* TOKEN_OFFSET  */
    TOKEN_STRING = 261,            /* TOKEN_STRING  */
    TOKEN_FUNCTION = 262,          /* TOKEN_FUNCTION  */
    TOKEN_IF = 263,                /* TOKEN_IF  */
    TOKEN_ELSE = 264,              /* TOKEN_ELSE  */
    TOKEN_OP_AND = 265,            /* TOKEN_OP_AND  */
    TOKEN_OP_OR = 266,             /* TOKEN_OP_OR  */
    TOKEN_OP_ASSIGN = 267,         /* TOKEN_OP_ASSIGN  */
    TOKEN_OP_INC = 268,            /* TOKEN_OP_INC  */
    TOKEN_OP_DEC = 269,            /* TOKEN_OP_DEC  */
    TOKEN_OP_CMP_NEQ = 270,        /* TOKEN_OP_CMP_NEQ  */
    TOKEN_OP_CMP_EQ = 271,         /* TOKEN_OP_CMP_EQ  */
    TOKEN_OP_CMP_LT = 272,         /* TOKEN_OP_CMP_LT  */
    TOKEN_OP_CMP_GT = 273,         /* TOKEN_OP_CMP_GT  */
    TOKEN_OP_CMP_LEQ = 274,        /* TOKEN_OP_CMP_LEQ  */
    TOKEN_OP_CMP_GEQ = 275,        /* TOKEN_OP_CMP_GEQ  */
    TOKEN_OP_END = 276,            /* TOKEN_OP_END  */
    TOKEN_PAR_OPEN = 277,          /* TOKEN_PAR_OPEN  */
    TOKEN_PAR_CLOSE = 278,         /* TOKEN_PAR_CLOSE  */
    TOKEN_BLK_BEGIN = 279,         /* TOKEN_BLK_BEGIN  */
    TOKEN_BLK_END = 280,           /* TOKEN_BLK_END  */
    TOKEN_UNKNOWN = 281,           /* TOKEN_UNKNOWN  */
    TOKEN_OP_SUB = 282,            /* TOKEN_OP_SUB  */
    TOKEN_OP_ADD = 283,            /* TOKEN_OP_ADD  */
    TOKEN_OP_MUL = 284,            /* TOKEN_OP_MUL  */
    TOKEN_OP_DIV = 285,            /* TOKEN_OP_DIV  */
    TOKEN_UMINUS = 286,            /* TOKEN_UMINUS  */
    TOKET_OP_AND = 287,            /* TOKET_OP_AND  */
    TOKET_OP_OR = 288,             /* TOKET_OP_OR  */
    TOKET_OP_NOT = 289             /* TOKET_OP_NOT  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 42 "etterfilter/ef_grammar.y"

   char *string;
   struct filter_op fop;
   /* used to create the compiler tree */
   struct block *blk;
   struct instruction *ins;
   struct ifblock *ifb;
   struct condition *cnd;

#line 108 "/startdir/src/ettercap-0.8.3.1/build-gtk/utils/ef_grammar.h"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE yylval;


int yyparse (void);


#endif /* !YY_YY_STARTDIR_SRC_ETTERCAP_0_8_3_1_BUILD_GTK_UTILS_EF_GRAMMAR_H_INCLUDED  */
